pagebotcocoa.strings package
============================

Submodules
----------

pagebotcocoa.strings.formattedstring module
-------------------------------------------

.. automodule:: pagebotcocoa.strings.formattedstring
   :members:
   :undoc-members:
   :show-inheritance:

pagebotcocoa.strings.pattern module
-----------------------------------

.. automodule:: pagebotcocoa.strings.pattern
   :members:
   :undoc-members:
   :show-inheritance:

pagebotcocoa.strings.textline module
------------------------------------

.. automodule:: pagebotcocoa.strings.textline
   :members:
   :undoc-members:
   :show-inheritance:

pagebotcocoa.strings.textrun module
-----------------------------------

.. automodule:: pagebotcocoa.strings.textrun
   :members:
   :undoc-members:
   :show-inheritance:

pagebotcocoa.strings.tmp module
-------------------------------

.. automodule:: pagebotcocoa.strings.tmp
   :members:
   :undoc-members:
   :show-inheritance:

pagebotcocoa.strings.tryinstallfont module
------------------------------------------

.. automodule:: pagebotcocoa.strings.tryinstallfont
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pagebotcocoa.strings
   :members:
   :undoc-members:
   :show-inheritance:
